<?php

namespace Drupal\payment_authnet;

/**
 * Provides helper functions for additional fields.
 */
trait AdditionalFieldsTrait {

  /**
   * Returns the list of additional fields to be sent to Authorize.net.
   *
   * @return array
   *   The list of available / supported fields grouped by categories.
   */
  protected function getAvailableFields() {
    return [
      'Billing Information' => [
        'first_name' => 'textfield',
        'last_name' => 'textfield',
      ],
    ];
  }

  /**
   * Converts human readable string into machine name.
   *
   * @param string $human_readable
   *   Human readable string.
   *
   * @return string
   *   Machine name (allowed characters - lowercase letters, numbers and '_').
   */
  protected function humanToMachine($human_readable) {
    return preg_replace('@[^a-z0-9_]+@', '_', strtolower($human_readable));
  }

  /**
   * Builds section wrapper for additional fields.
   *
   * @param string $section_human_name
   *   Section title.
   *
   * @return array
   *   Form element wrapper array ('details' type).
   */
  protected function buildSectionWrapper($section_human_name) {
    $section_name = $this->humanToMachine($section_human_name);
    $result[$section_name] = [
      '#type' => 'details',
      '#title' => t($section_human_name),
      '#tree' => TRUE,
    ];
    return $result;
  }

}
