<?php

namespace Drupal\payment_authnet\Plugin\Payment\Method;

use Drupal\payment\Plugin\Payment\Method\PaymentMethodInterface;

/**
 * An interface for Authnet payment method.
 */
interface AuthnetInterface extends PaymentMethodInterface {

  /**
   * Detects if authorize.net should transfer money right now.
   *
   * @return string
   *   Transaction type for Authorize net to identify will money be charged
   *   right now, or credit card will be just authorized.
   *
   * @throws \LogicException
   */
  public function getTransactionType();

  /**
   * Gets detailed information about a last Authorize.net transaction.
   *
   * @param bool $refresh
   *   If false, request will be cached and next time returned from cache.
   *
   * @return \net\authorize\api\contract\v1\TransactionDetailsType
   *   Instance of getTransactionDetailsResponse.
   *
   * @throws Exception\PaymentAuthnetApiException
   * @throws Exception\PaymentAuthnetResponseException
   */
  public function getTransactionDetails($refresh = FALSE);

  /**
   * Gets the Authnet transaction's refId.
   *
   * @return string
   *   The Authnet refId (string up to 20 characters).
   */
  public function getRefId();

}
